# Generated by Django 4.0.5 on 2022-06-19 12:53

from django.db import migrations, models
import odk.models


class Migration(migrations.Migration):

    dependencies = [
        ('odk', '0002_remove_xformsubmit_xform'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='xform',
            name='modified_by',
        ),
        migrations.RemoveField(
            model_name='xform',
            name='modified_on',
        ),
        migrations.RemoveField(
            model_name='xformsubmit',
            name='modified_by',
        ),
        migrations.RemoveField(
            model_name='xformsubmit',
            name='modified_on',
        ),
        migrations.AddField(
            model_name='xform',
            name='model_created_on',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Model created on'),
        ),
        migrations.AddField(
            model_name='xformsubmit',
            name='inserted_on',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Inserted on'),
        ),
        migrations.AlterField(
            model_name='xform',
            name='xml_file',
            field=models.FileField(blank=True, help_text="XLSForm converted by <a href='https://getodk.org/xlsform/' target='_blank'>https://getodk.org/xlsform/</a>", null=True, upload_to=odk.models.xform_path, verbose_name='XML file'),
        ),
    ]
