# Generated by Django 3.2.9 on 2021-11-24 09:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('odk', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='xformsubmit',
            name='xform',
        ),
    ]
