{% extends "base.html" %}
{% load i18n %}

{% block title %}{{ title }}{% endblock title %}

{% block content_title %}<h2>{{ title }}</h2>{% endblock %}

{% block content %}

<p><a href="https://xlsform.org/en/" target="_blank">{% blocktrans %}What is an XLSForm?{% endblocktrans %}</a></p>

<p><a href="https://docs.getodk.org/xlsform/" target="_blank">{% blocktrans %}XLSForm Documentation{% endblocktrans %}</a></p>

<p><a href="https://docs.google.com/spreadsheets/d/1v9Bumt3R0vCOGEKQI6ExUf2-8T72-XXp_CbKKTACuko/edit#gid=0" target="_blank">
    {% blocktrans %}XLSForm example{% endblocktrans %}</a></p>

<p><a href="https://getodk.github.io/xforms-spec/" target="_blank">{% blocktrans %}ODK XForms Specifications{% endblocktrans %}</a></p>

<br/>

<a class="btn btn-secondary" href="{% url 'odk:xform_add' %}">{% trans 'Back' %}</a>

{% endblock content %}
