{% load i18n %}

<h4>{% blocktrans %}STEPS{% endblocktrans %}</h4>

<ul style="list-style-type: none;">
    <li class="my-1"><button class="btn btn-primary" style="width: 130px;">Build</button>&nbsp;{% blocktrans %}Build an XLSForm file with 3 tabs 'survey', 'choices', 'settings' {% endblocktrans %}<a href="{% url 'odk:xform_doc' %}">Cfr documentation</a></li>
    <li class="my-1"><button class="btn btn-secondary" style="width: 130px;">Upload</button>&nbsp;{% blocktrans %}Upload xlsx file (XForm) by clicking on 'Choose file' and Save{% endblocktrans %}</li>
    <li class="my-1"><button class="btn btn-danger" style="width: 130px;">Convert2XML</button>&nbsp;{% blocktrans %}Convert xlsx file to xml compatible file{% endblocktrans %}</li>
    <li class="my-1"><button class="btn btn-success" style="width: 130px;">CreateModel</button>&nbsp;{% blocktrans %}Create final storage model{% endblocktrans %}</li>
</ul>




